summaryrefslogtreecommitdiff
path: root/gcc/config/c4x
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-17 23:10:04 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-17 23:10:04 +0000
commite3e08e7f98ee1087965502514cbc359cc4cfeb18 (patch)
tree8bbd60963b5ab609c8683955c3761d6dde0daf0f /gcc/config/c4x
parent7af58cc3716d762eb808271581943b1aa12f9992 (diff)
downloadgcc-e3e08e7f98ee1087965502514cbc359cc4cfeb18.tar.gz
* config/alpha/alpha.c: Follow spelling conventions.
* config/alpha/alpha.h: Likewise. * config/alpha/alpha.md: Likewise. * config/arc/arc.h: Likewise. * config/arm/arm.c: Likewise. * config/arm/arm.h: Likewise. * config/arm/arm.md: Likewise. * config/arm/pe.c: Likewise. * config/arm/unknown-elf.h: Likewise. * config/avr/avr.c: Likewise. * config/avr/avr.h: Likewise. * config/c4x/c4x.c: Likewise. * config/cris/cris.c: Likewise. * config/cris/cris.h: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@57266 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/c4x')
-rw-r--r--gcc/config/c4x/c4x.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/config/c4x/c4x.c b/gcc/config/c4x/c4x.c
index c394fe34d10..83ab33124ff 100644
--- a/gcc/config/c4x/c4x.c
+++ b/gcc/config/c4x/c4x.c
@@ -436,7 +436,7 @@ c4x_hard_regno_mode_ok (regno, mode)
return 0;
}
/* Return non-zero if REGNO1 can be renamed to REGNO2. */
int
c4x_hard_regno_rename_ok (regno1, regno2)
unsigned int regno1;
@@ -3366,10 +3366,10 @@ src_operand (op, mode)
|| GET_CODE (op) == CONST)
return 0;
/* If TARGET_LOAD_DIRECT_MEMS is non-zero, disallow direct memory
access to symbolic addresses. These operands will get forced
into a register and the movqi expander will generate a
- HIGH/LO_SUM pair if TARGET_EXPOSE_LDP is non-zero. */
+ HIGH/LO_SUM pair if TARGET_EXPOSE_LDP is nonzero. */
if (GET_CODE (op) == MEM
&& ((GET_CODE (XEXP (op, 0)) == SYMBOL_REF
|| GET_CODE (XEXP (op, 0)) == LABEL_REF
@@ -436,7 +436,7 @@ c4x_hard_regno_mode_ok (regno, mode)
return 0;
}
-/* Return non-zero if REGNO1 can be renamed to REGNO2. */
+/* Return nonzero if REGNO1 can be renamed to REGNO2. */
int
c4x_hard_regno_rename_ok (regno1, regno2)
@@ -3366,10 +3366,10 @@ src_operand (op, mode)
|| GET_CODE (op) == CONST)
return 0;
- /* If TARGET_LOAD_DIRECT_MEMS is non-zero, disallow direct memory
+ /* If TARGET_LOAD_DIRECT_MEMS is nonzero, disallow direct memory
access to symbolic addresses. These operands will get forced
into a register and the movqi expander will generate a